{% macro test_macro_static() %}
    STATIC MACRO
{% endmacro %}

{% macro test_macro_with_content(c) %}
    {{c['any']}}
{% endmacro %}

{% macro test_macro_with_attr(v) %}
    {{v.anything}}
{% endmacro %}

{% macro test_macro_general(v) %}
{% endmacro %}

{% macro test_macro_independent(v) %}
    {{v.iam}}
{% endmacro %}

{% macro test_macro_tab_content(v) %}
    {{v.iam}}
{% endmacro %}

{% macro test_named_macro(v) %}
    A NAMED MACRO RENDERED BY NAME
{% endmacro %}
