{% macro listmacro(l) %}
    <{{l.kind}}{%if l.css_id%} id='{{l.css_id}}'{%endif%}{%if l.css_class%} class='{{l.css_class}}'{%endif%}>
        {% for item in l.list_items %}
            {{item.render|safe}}
        {% endfor %}
    </{{l.kind}}>
{% endmacro %}

{% macro _li_enclosure(item) %}
    {%if item.li%}<li{%if item.css_class%} class="{{item.css_class}}"{%endif%}>{%endif%}{{ caller() }}{%if item.li%}</li>{%endif%}
{% endmacro %}

{% macro plainitem(li) %}
    {% call _li_enclosure(li) %}{{li.li_tag}}{% endcall %}
{% endmacro %}

{% macro linkitem(li) %}
    {% call _li_enclosure(li) %}<a href="{{li.url()}}">{{li.li_tag}}</a>{% endcall %}
{% endmacro %}

{% macro macroitem(li) %}
    {{li.li_tag.render|safe}}
{% endmacro %}
